write_wal

Function write_wal 

async fn write_wal<S: LogStore>(
    wal: &Wal<S>,
    region_ctxs: &mut HashMap<RegionId, RegionWriteCtx>,
) -> bool
Writes WAL entries of all region contexts to the WAL in one batch and updates the next entry id of each region on success.

Returns false if the batch fails to be written to the WAL. In this case all contexts are consumed and their waiters are notified with the error, so the caller should skip the memtable phase.